import { Component, ViewChild, ViewEncapsulation, Inject, HostListener, Injectable, ɵɵdefineInjectable, ɵɵinject, ViewContainerRef, ChangeDetectorRef, EventEmitter, Input, Output, NgModule } from '@angular/core';
import { OverlayModule } from '@angular/cdk/overlay';
import { FormGroup, FormControl, Validators, FormBuilder, FormArray, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { ActivatedRoute, Router, RouterModule } from '@angular/router';
import { Utilities, IFormView, DynaDataService, AuditDialogService, ConfirmationDialogService, ValidatorUtils, XdfGalleryModule } from '@xdf/gallery';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialog, MatFormFieldModule, MatSelectModule, MatOptionModule, MatInputModule, MatButtonModule, MatCheckboxModule } from '@angular/material';
import { NotificationType, NotificationService, InitCommonsService } from '@xdf/commons';
import { TranslateService, TranslateModule } from '@ngx-translate/core';
import { NavigationService } from '@xdf/layouts';
import { map } from 'rxjs/operators';
import { MatDialog as MatDialog$1 } from '@angular/material/dialog';
import { HttpClient } from '@angular/common/http';
import { BehaviorSubject } from 'rxjs';
import { NgScrollbarModule } from 'ngx-scrollbar';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const SettingOptions = {
    INFO: 'information',
    PASSWORD: 'password',
    USERPOLICY: 'userpolicy',
    MAIL: 'mail',
};
class SystemSettingsComponent {
    /**
     * @param {?} route
     * @param {?} router
     */
    constructor(route, router) {
        this.route = route;
        this.router = router;
        this.selected = 'information';
        this.mode = 'view';
        this.basePath = "/settings/system-settings";
    }
    /**
     * Método utilizado para saber si un formulario ha sido modificado
     * @return {?}
     */
    isDirty() {
        return this.viewDirty.isDirty();
    }
    /**
     * @return {?}
     */
    getRef() {
        return this.viewDirty.getRef();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.templateDefinition = this.route.snapshot.data.template;
        /** @type {?} */
        const option = this.route.snapshot.data['option'];
        this.mode = this.route.snapshot.paramMap.get('mode');
        if (!this.mode)
            this.mode = 'view';
        if (option) {
            if (!Utilities.existValueInEnum(SettingOptions, option)) {
                this.router.navigate(['/notfound']);
                return;
            }
            this.selected = option;
        }
    }
    /**
     * @param {?} view
     * @return {?}
     */
    changeView(view) {
        this.router.navigate([this.basePath + '/' + view]);
    }
}
SystemSettingsComponent.decorators = [
    { type: Component, args: [{
                selector: 'xdf-system-settings',
                template: "<div class=\"wrapper wrapper-content\">\n    <div class=\"row\">\n        <div class=\"col-12 d-block d-lg-none d-xl-none\">\n            <div class=\"float-e-margins\">\n                <div class=\"ibox-content mailbox-content mini pull-right\">\n                    <mat-form-field>\n                        <mat-select [value]=\"selected\" (selectionChange)=\"changeView($event.value)\">\n                            <mat-option value=\"information\">{{ 'settings.general.information.short' | translate }}</mat-option>\n                            <mat-option value=\"password\">{{ 'settings.security.password.short' | translate }}</mat-option>\n                            <mat-option value=\"userpolicy\">{{ 'settings.security.user.policy.short' | translate }}</mat-option>\n                            <!-- <mat-option value=\"mail\">{{ 'settings.notification.mail.short' | translate }}</mat-option> -->\n                        </mat-select>\n                    </mat-form-field>\n                </div>\n            </div>\n        </div>\n    </div>\n    <div class=\"row\">\n        <div class=\"col-4 col-xl-3 d-none d-lg-block d-xl-block\">\n            <div class=\"float-e-margins\">\n                <div class=\"ibox-content mailbox-content\">\n                    <div class=\"file-manager\">\n                        <h5>{{ 'settings.general.header' | translate }}</h5>\n                        <ul class=\"folder-list m-b-md\">\n                            <li [ngClass]=\"{'active': selected === 'information'}\"><a (click)=\"changeView('information')\"> <i class=\"fa fa-info-circle\"></i>\n                                    {{ 'settings.general.information.short' | translate }}</a></li>\n                        </ul>\n                        <h5>{{ 'settings.security.header' | translate }}</h5>\n                        <ul class=\"folder-list m-b-md\">\n                            <li [ngClass]=\"{'active': selected === 'password'}\"><a (click)=\"changeView('password')\"> <i\n                                        class=\"fa  fa-key\"></i> {{ 'settings.security.password.short' | translate }}</a></li>\n                            <li [ngClass]=\"{'active': selected === 'userpolicy'}\"><a (click)=\"changeView('userpolicy')\"> <i\n                                        class=\"fa fa-user-secret\"></i> {{ 'settings.security.user.policy.short' | translate }}</a></li>\n                        </ul>\n                        <!-- <div class=\"space-15\"></div>\n                        <h5>{{ 'settings.notification.header' | translate }}</h5>\n                        <ul class=\"folder-list m-b-md\">\n                            <li [ngClass]=\"{'active': selected === 'mail'}\"><a (click)=\"changeView('mail')\"> <i\n                                        class=\"fa fa-envelope-o\"></i> {{ 'settings.notification.mail.short' | translate }}</a></li>\n                        </ul> -->\n                        <div class=\"clearfix\"></div>\n                    </div>\n                </div>\n            </div>\n        </div>\n \n        <div class=\"col-12 col-lg-8 col-xl-9 animated fadeInRight\" data-ui-view>\n            <xdf-form-view #content_form *ngIf=\"selected === 'information'\" [mode]=\"mode\" [showBack]=\"false\" [resetForm]=\"false\"></xdf-form-view>\n            <xdf-form-view #content_form *ngIf=\"selected === 'password'\" [mode]=\"mode\" [showBack]=\"false\" [resetForm]=\"false\"></xdf-form-view>\n            <xdf-form-view #content_form *ngIf=\"selected === 'userpolicy'\" [mode]=\"mode\" [showBack]=\"false\" [resetForm]=\"false\"></xdf-form-view>\n            <!-- <xdf-setting-mail #content_form *ngIf=\"selected === 'mail'\"></xdf-setting-mail> -->\n            \n            \n        </div>\n    </div>\n</div>",
                styles: [".mini{padding:0}.ibox-content h4{margin:0}.folder-list{padding:0}.folder-list li{padding:0 0 0 10px;white-space:nowrap;border-bottom:0}.folder-list li.active{background-color:#fff}.file-manager h5{margin:0}::ng-deep .user-policy xdf-checkbox{font-size:10px!important}"]
            }] }
];
/** @nocollapse */
SystemSettingsComponent.ctorParameters = () => [
    { type: ActivatedRoute },
    { type: Router }
];
SystemSettingsComponent.propDecorators = {
    viewDirty: [{ type: ViewChild, args: ['content_form', { static: false },] }]
};
if (false) {
    /** @type {?} */
    SystemSettingsComponent.prototype.viewDirty;
    /** @type {?} */
    SystemSettingsComponent.prototype.selected;
    /** @type {?} */
    SystemSettingsComponent.prototype.mode;
    /** @type {?} */
    SystemSettingsComponent.prototype.templateDefinition;
    /** @type {?} */
    SystemSettingsComponent.prototype.basePath;
    /**
     * @type {?}
     * @protected
     */
    SystemSettingsComponent.prototype.route;
    /**
     * @type {?}
     * @protected
     */
    SystemSettingsComponent.prototype.router;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function DialogData() { }
if (false) {
    /** @type {?} */
    DialogData.prototype.data;
}
class ViewCredencialsDialogComponent {
    /**
     * @param {?} dialogRef
     * @param {?} dataDialog
     */
    constructor(dialogRef, dataDialog) {
        this.dialogRef = dialogRef;
        this.dataDialog = dataDialog;
        this.data = this.dataDialog.data;
        this.form = new FormGroup({
            clientId: new FormControl({ value: this.data['clientId'], disabled: true }),
            clientSecret: new FormControl({ value: this.data['clientSecret'], disabled: true }),
            accessTokenValidity: new FormControl({ value: this.data['accessTokenValidity'], disabled: true }),
            refreshTokenValidity: new FormControl({ value: this.data['refreshTokenValidity'], disabled: true })
        });
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    closeDialog() {
        this.dialogRef.close();
    }
    /**
     * @return {?}
     */
    onKeyUp() {
        this.dialogRef.close();
    }
}
ViewCredencialsDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'xdf-view-credencials-dialog',
                template: "<div class=\"close\">\n    <i class=\"fa fa-close\" (click)=\"closeDialog()\"></i>\n</div>\n<h1 mat-dialog-title class=\"dialog-title\">\n    {{ 'application_credentials_title' | translate}}\n</h1>\n<div mat-dialog-content class=\"dialog-content\">\n    <div class=\"group-content\" [formGroup]=\"form\">\n        <div class=\"row justify-content-md-center\">\n            <div class=\"form-group col-12\">\n                <xdf-input name=\"clientId\" label=\"application_form_client_id_placeholder\" \n                    type=\"text\" [required]=\"true\"\n                    placeholder=\"application_form_client_id_placeholder\" \n                    disabled=\"true\" [formGroup]=\"form\">\n                </xdf-input>\n            </div>\n            <div class=\"form-group col-12\">\n                <xdf-input name=\"clientSecret\" label=\"application_form_client_secret_placeholder\" \n                    type=\"text\" [required]=\"true\"\n                    placeholder=\"application_form_client_secret_placeholder\" \n                    disabled=\"true\" [formGroup]=\"form\">\n                </xdf-input>\n            </div>\n            <div class=\"form-group col-12\">\n                <xdf-input name=\"accessTokenValidity\" label=\"application_form_access_token_validity_placeholder\" \n                    type=\"text\" [required]=\"true\"\n                    placeholder=\"application_form_access_token_validity_placeholder\" \n                    disabled=\"true\" [formGroup]=\"form\">\n                </xdf-input>\n            </div>\n            <div class=\"form-group col-12\">\n                <xdf-input name=\"refreshTokenValidity\" label=\"application_form_refresh_token_validity_placeholder\" \n                    type=\"text\" [required]=\"true\"\n                    placeholder=\"application_form_refresh_token_validity_placeholder\" \n                    disabled=\"true\" [formGroup]=\"form\">\n                </xdf-input>\n            </div>\n        </div>\n    </div>\n</div>\n<div mat-dialog-actions class=\"border-top dialog-footer\">\n    <button type=\"button\" mat-button class=\"pull-right\" (click)=\"closeDialog()\">{{'btn.close' | translate}} </button>\n</div>",
                encapsulation: ViewEncapsulation.None,
                styles: [".dialog-footer button{margin-top:10px}.dialog-content{color:#676a6c}.close{cursor:pointer;margin-top:-10px;font-size:15px}"]
            }] }
];
/** @nocollapse */
ViewCredencialsDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];
ViewCredencialsDialogComponent.propDecorators = {
    onKeyUp: [{ type: HostListener, args: ['window:keyup.esc',] }]
};
if (false) {
    /** @type {?} */
    ViewCredencialsDialogComponent.prototype.data;
    /** @type {?} */
    ViewCredencialsDialogComponent.prototype.form;
    /** @type {?} */
    ViewCredencialsDialogComponent.prototype.dialogRef;
    /** @type {?} */
    ViewCredencialsDialogComponent.prototype.dataDialog;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function ChangeSecretDialogData() { }
if (false) {
    /** @type {?} */
    ChangeSecretDialogData.prototype.id;
    /** @type {?} */
    ChangeSecretDialogData.prototype.service;
}
class ChangeSecretDialogComponent {
    /**
     * @param {?} dialogRef
     * @param {?} dataDialog
     * @param {?} notificationservice
     * @param {?} translateService
     */
    constructor(dialogRef, dataDialog, notificationservice, translateService) {
        this.dialogRef = dialogRef;
        this.dataDialog = dataDialog;
        this.notificationservice = notificationservice;
        this.translateService = translateService;
        this.disabledButton = false;
        this.id = this.dataDialog.id;
        this.service = this.dataDialog.service;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    change() {
        this.disabledButton = true;
        this.service.generateSecret(this.id).subscribe((/**
         * @param {?} result
         * @return {?}
         */
        result => {
            /** @type {?} */
            const message = this.translateService.instant('application_new_secret_success');
            this.dialogRef.close({ success: true, clientId: result['clientId'], secret: result['secret'] });
            this.notificationservice.showMessage('', message, NotificationType.success);
            this.disabledButton = false;
        }));
    }
    /**
     * @return {?}
     */
    closeDialog() {
        this.dialogRef.close({ success: false });
    }
    /**
     * @return {?}
     */
    onKeyUp() {
        this.dialogRef.close({ success: false });
    }
}
ChangeSecretDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'xdf-example-change-secret-dialog',
                template: "<div class=\"close\">\n    <i class=\"fa fa-close\" (click)=\"closeDialog()\"></i>\n</div>\n<h1 mat-dialog-title class=\"dialog-title\">\n    <i class=\"fa fa-exclamation-triangle\"></i>{{ 'application_generated_secret_title' | translate}}\n</h1>\n<div mat-dialog-content class=\"dialog-content\">\n   <p>{{ 'application_generated_secret_message' | translate }}</p>\n</div>\n<div mat-dialog-actions class=\"border-top dialog-footer\">\n    <button type=\"button\" mat-button [disabled]=\"disabledButton\" (click)=\"closeDialog()\">{{'btn.no' | translate}} </button>\n    <button type=\"button\" mat-button [disabled]=\"disabledButton\" (click)=\"change()\">{{'btn.yes' | translate}} </button>\n</div>",
                encapsulation: ViewEncapsulation.None,
                styles: [".dialog-footer button{margin-top:10px}.dialog-content{color:#676a6c}.close{cursor:pointer;margin-top:-10px;font-size:15px}.dialog-title i{font-size:28px;padding-right:20px;color:red}"]
            }] }
];
/** @nocollapse */
ChangeSecretDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] },
    { type: NotificationService },
    { type: TranslateService }
];
ChangeSecretDialogComponent.propDecorators = {
    onKeyUp: [{ type: HostListener, args: ['window:keyup.esc',] }]
};
if (false) {
    /** @type {?} */
    ChangeSecretDialogComponent.prototype.id;
    /** @type {?} */
    ChangeSecretDialogComponent.prototype.service;
    /** @type {?} */
    ChangeSecretDialogComponent.prototype.disabledButton;
    /** @type {?} */
    ChangeSecretDialogComponent.prototype.dialogRef;
    /** @type {?} */
    ChangeSecretDialogComponent.prototype.dataDialog;
    /**
     * @type {?}
     * @protected
     */
    ChangeSecretDialogComponent.prototype.notificationservice;
    /**
     * @type {?}
     * @protected
     */
    ChangeSecretDialogComponent.prototype.translateService;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ChangeSecretDialogService {
    /**
     * @param {?} dialog
     */
    constructor(dialog) {
        this.dialog = dialog;
    }
    /**
     * @param {?} id
     * @param {?} service
     * @return {?}
     */
    loadComponent(id, service) {
        this.componentRef = this.dialog.open(ChangeSecretDialogComponent, {
            width: '500px',
            disableClose: true,
            data: {
                id: id,
                service: service
            }
        });
        return this.componentRef.afterClosed().pipe(map((/**
         * @param {?} it
         * @return {?}
         */
        it => {
            return it;
        })));
    }
}
ChangeSecretDialogService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
ChangeSecretDialogService.ctorParameters = () => [
    { type: MatDialog }
];
/** @nocollapse */ ChangeSecretDialogService.ngInjectableDef = ɵɵdefineInjectable({ factory: function ChangeSecretDialogService_Factory() { return new ChangeSecretDialogService(ɵɵinject(MatDialog$1)); }, token: ChangeSecretDialogService, providedIn: "root" });
if (false) {
    /** @type {?} */
    ChangeSecretDialogService.prototype.answer;
    /** @type {?} */
    ChangeSecretDialogService.prototype.componentRef;
    /** @type {?} */
    ChangeSecretDialogService.prototype.dialog;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const basePath = "./service/application";
class ApplicationService {
    /**
     * @param {?} http
     */
    constructor(http) {
        this.http = http;
    }
    /**
     * @param {?} id
     * @return {?}
     */
    generateSecret(id) {
        return this.http.get(basePath + '/generate-secret/' + id);
    }
}
ApplicationService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
ApplicationService.ctorParameters = () => [
    { type: HttpClient }
];
/** @nocollapse */ ApplicationService.ngInjectableDef = ɵɵdefineInjectable({ factory: function ApplicationService_Factory() { return new ApplicationService(ɵɵinject(HttpClient)); }, token: ApplicationService, providedIn: "root" });
if (false) {
    /**
     * @type {?}
     * @private
     */
    ApplicationService.prototype.http;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ViewCredencialsDialogService {
    /**
     * @param {?} dialog
     */
    constructor(dialog) {
        this.dialog = dialog;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    loadComponent(data) {
        this.componentRef = this.dialog.open(ViewCredencialsDialogComponent, {
            width: '500px',
            disableClose: true,
            data: {
                data: data
            }
        });
        return this.componentRef.afterClosed().pipe(map((/**
         * @param {?} it
         * @return {?}
         */
        it => {
            return it;
        })));
    }
}
ViewCredencialsDialogService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
ViewCredencialsDialogService.ctorParameters = () => [
    { type: MatDialog }
];
/** @nocollapse */ ViewCredencialsDialogService.ngInjectableDef = ɵɵdefineInjectable({ factory: function ViewCredencialsDialogService_Factory() { return new ViewCredencialsDialogService(ɵɵinject(MatDialog$1)); }, token: ViewCredencialsDialogService, providedIn: "root" });
if (false) {
    /** @type {?} */
    ViewCredencialsDialogService.prototype.answer;
    /** @type {?} */
    ViewCredencialsDialogService.prototype.componentRef;
    /** @type {?} */
    ViewCredencialsDialogService.prototype.dialog;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ApplicationFormComponent extends IFormView {
    /**
     * @param {?} vcRef
     * @param {?} route
     * @param {?} router
     * @param {?} dynaDataService
     * @param {?} translate
     * @param {?} notificationService
     * @param {?} auditDialogService
     * @param {?} confirmationDialogService
     * @param {?} navigationService
     * @param {?} validatorUtils
     * @param {?} viewCredencialsService
     * @param {?} changeSecretService
     * @param {?} applicationService
     * @param {?} init
     */
    constructor(vcRef, route, router, dynaDataService, translate, notificationService, auditDialogService, confirmationDialogService, navigationService, validatorUtils, viewCredencialsService, changeSecretService, applicationService, init) {
        super(vcRef, route, router, dynaDataService, translate, notificationService, auditDialogService, confirmationDialogService, init);
        this.vcRef = vcRef;
        this.route = route;
        this.router = router;
        this.dynaDataService = dynaDataService;
        this.translate = translate;
        this.notificationService = notificationService;
        this.auditDialogService = auditDialogService;
        this.confirmationDialogService = confirmationDialogService;
        this.navigationService = navigationService;
        this.validatorUtils = validatorUtils;
        this.viewCredencialsService = viewCredencialsService;
        this.changeSecretService = changeSecretService;
        this.applicationService = applicationService;
        this.init = init;
        this.statusOptions = {
            "styles": {
                "A": "label label-primary",
                "I": "label label-danger"
            }
        };
        this.statusValues = [
            {
                id: "A",
                label: "application.status.active",
                value: "A",
                selected: false,
            },
            {
                id: "I",
                label: "application.status.inactive",
                value: "I",
                selected: false,
            }
        ];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
    }
    /**
     * @return {?}
     */
    submit() {
        this.processing = true;
        /** @type {?} */
        const keyVersion = "version";
        /** @type {?} */
        const version = this.record ? this.record[keyVersion] : undefined;
        this.record = this.form.value;
        /** @type {?} */
        const keyProps = Object.keys(this.record);
        keyProps.forEach((/**
         * @param {?} keyProp
         * @return {?}
         */
        keyProp => {
            /** @type {?} */
            const value = this.record[keyProp];
            this.record[keyProp] = Utilities.formatValue(this.attributeTypes, keyProp, value);
        }));
        this.record[keyVersion] = version;
        if (this.mode === "new") {
            this.dynaDataService.create(this.record).subscribe((/**
             * @param {?} it
             * @return {?}
             */
            it => {
                /** @type {?} */
                const title = this.translate.instant("title.information");
                /** @type {?} */
                const message = this.translate.instant("message.create.succesful");
                this.notificationService.showMessage(message, title, NotificationType.success);
                this.dataDialog = this.getDataDialog(it);
                this.viewCredencialsService.loadComponent(this.dataDialog).subscribe((/**
                 * @param {?} result
                 * @return {?}
                 */
                result => {
                    this.record = new Object();
                    this.form.reset();
                    this.processing = false;
                }));
            }), (/**
             * @param {?} error
             * @return {?}
             */
            error => {
                this.processing = false;
            }));
        }
        else if (this.mode === "edit") {
            /** @type {?} */
            const record = this.record;
            /** @type {?} */
            const keyId = "id";
            record[keyId] = this.id;
            this.dynaDataService.update(this.id, record).subscribe((/**
             * @param {?} it
             * @return {?}
             */
            it => {
                /** @type {?} */
                const title = this.translate.instant("title.information");
                /** @type {?} */
                const message = this.translate.instant("message.update.succesful");
                this.notificationService.showMessage(message, title, NotificationType.success);
                this.processing = false;
                this.form.markAsPristine();
                this.router.navigate([this.returnUrl]);
            }), (/**
             * @param {?} error
             * @return {?}
             */
            error => {
                this.processing = false;
            }));
        }
    }
    /**
     * @private
     * @param {?} record
     * @return {?}
     */
    getDataDialog(record) {
        /** @type {?} */
        const data = record ? {
            clientId: record['clientId'],
            clientSecret: record['clientSecret'],
            accessTokenValidity: record['accessTokenValidity'],
            refreshTokenValidity: record['refreshTokenValidity']
        } : {};
        return data;
    }
    /**
     * @protected
     * @return {?}
     */
    getFields() {
        /** @type {?} */
        let form;
        /** @type {?} */
        const regex = /^http:\/\/\w+(\.\w+)*(:[0-9]+)?\/?(\/[.\w]*)*$/;
        if (this.record) {
            form = new FormGroup({
                id: new FormControl({ value: this.record['id'], disabled: this.disabledCondition('id') }, Validators.required),
                identifier: new FormControl({ value: this.record['identifier'], disabled: this.disabledCondition() }, [Validators.required]),
                description: new FormControl({ value: this.record['description'], disabled: this.disabledCondition() }, Validators.required),
                redirectURL: new FormControl({ value: this.record['redirectURL'], disabled: this.disabledCondition() }, [Validators.required, Validators.pattern(regex)]),
                status: new FormControl({ value: this.record['status'], disabled: true })
            });
        }
        else {
            form = new FormGroup({
                id: new FormControl({ value: '', disabled: this.disabledCondition('id') }, Validators.required),
                identifier: new FormControl({ value: '', disabled: this.disabledCondition() }, Validators.required),
                description: new FormControl({ value: '', disabled: this.disabledCondition() }, Validators.required),
                redirectURL: new FormControl({ value: '', disabled: this.disabledCondition() }, [Validators.required, Validators.pattern(regex)]),
                status: new FormControl()
            });
        }
        this.dataDialog = this.getDataDialog(this.record);
        return form;
    }
    /**
     * @param {?=} controlName
     * @return {?}
     */
    disabledCondition(controlName) {
        /** @type {?} */
        const disabled = this.mode === "view" || controlName === "id";
        return disabled;
    }
    /**
     * @return {?}
     */
    changeSecret() {
        this.changeSecretService.loadComponent(this.id, this.applicationService).subscribe((/**
         * @param {?} result
         * @return {?}
         */
        result => {
            if (result['success']) {
                this.dataDialog['clientSecret'] = result['secret'];
                this.dataDialog['clientId'] = result['clientId'];
            }
        }));
    }
    /**
     * @return {?}
     */
    showCredentials() {
        this.viewCredencialsService.loadComponent(this.dataDialog).subscribe((/**
         * @param {?} result
         * @return {?}
         */
        result => { }));
    }
}
ApplicationFormComponent.decorators = [
    { type: Component, args: [{
                selector: 'xdf-example-application-form',
                template: "<form [formGroup]=\"form\" name=\"form\" autocomplete=\"off\" novalidate (ngSubmit)=\"submit()\">\n    <div class=\"row\">\n        <div class=\"col-12\">\n            <div class=\"mail-box-header detail-header\">\n                <xdf-form-header title_=\"application.title\" [icon]=\"icon\" [recordIdentifier]=\"record?.identifier\"\n                    [mode]=\"mode\" [resourceAuth]=\"resourceAuth\" (optionEvent)=\"optionEvent($event)\"\n                    [editing]=\"mode === 'edit'\" [displaying]=\"mode === 'view'\">\n                </xdf-form-header>\n            </div>\n\n            <div class=\"mail-box-content\">\n                <div class=\"row\">\n                    <div class=\"col-12\">\n                        <div class=\"form-content\">\n                            <div class=\"group-content\">\n                                <div class=\"legend\">\n                                    <span class=\"group-title\">{{ 'application_group_general_information' | translate }}</span>\n                                    \n                                    <div class=\"pull-right application-options\" *ngIf=\"mode !== 'new'\">\n                                        <button type=\"button\" class=\"btn btn-default btn-sm\" (click)=\"changeSecret()\"\n                                            *ngIf=\"mode !== 'view'\"><span\n                                                class=\"btn-label\">{{ 'application_btn_new_secret' |translate }}</span></button>\n                                        <button type=\"button\" class=\"btn btn-default btn-sm\"\n                                            (click)=\"showCredentials()\"><span\n                                                class=\"btn-label\">{{ 'application_btn_show_credentials' |translate }}</span></button>\n                                    </div>\n                                </div>\n                                <div class=\"row\">\n                                    <div class=\"form-group col-6\">\n                                        <xdf-input name=\"identifier\" label=\"application_form_identifier_placeholder\"\n                                            type=\"text\" [required]=\"true\"\n                                            placeholder=\"application_form_identifier_placeholder\" [formGroup]=\"form\"\n                                            [options]=\"{'maxLength': 20, 'showLength': true}\">\n                                        </xdf-input>\n                                    </div>\n                                    <div class=\"form-group col-6\">\n                                        <xdf-badge name=\"status\" [values]=\"statusValues\"\n                                            formControlName=\"status\" [options]=\"statusOptions\">\n                                        </xdf-badge>\n                                    </div>\n                                </div>\n                                <div class=\"row\">\n                                    <div class=\"form-group col-6\">\n                                        <xdf-input name=\"description\" label=\"application_form_description_placeholder\"\n                                            type=\"text\" [required]=\"true\"\n                                            placeholder=\"application_form_description_placeholder\" [formGroup]=\"form\"\n                                            [options]=\"{'maxLength': 100, 'showLength': true}\">\n                                        </xdf-input>\n\n                                    </div>\n                                    <div class=\"form-group col-6\">\n                                        <xdf-input name=\"redirectURL\" label=\"application_form_redirectURL_placeholder\"\n                                            type=\"text\" [required]=\"true\"\n                                            placeholder=\"application_form_redirectURL_placeholder\" [formGroup]=\"form\"\n                                            [options]=\"{'maxLength': 100, 'showLength': true}\">\n                                        </xdf-input>\n                                    </div>\n                                </div>\n                            </div>\n                        </div>\n                    </div>\n                </div>\n                <div class=\"row\">\n                    <div class=\"col-lg-12\" *ngIf=\"mode !== 'view'\">\n                        <div class=\"form-status-bar border-top\">\n                            <button type=\"submit\" mat-stroked-button class=\"btn btn-primary\"\n                                [disabled]=\"form?.invalid || processing\">\n                                <i class=\"fa fa-save\" aria-hidden=\"true\"></i>{{'btn.save' | translate}}\n                            </button>\n                        </div>\n                    </div>\n                </div>\n            </div>\n        </div>\n    </div>\n</form>",
                styles: [".form-status-bar{padding:10px 0}.form-status-bar button{color:#fff;font-size:12px;float:right;font-weight:500}.form-status-bar button i{padding-right:5px}.form-content{margin:10px 20px}.label-access{padding-bottom:7px}.application-options button{color:#676a6c;font-size:10px!important}"]
            }] }
];
/** @nocollapse */
ApplicationFormComponent.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: ActivatedRoute },
    { type: Router },
    { type: DynaDataService },
    { type: TranslateService },
    { type: NotificationService },
    { type: AuditDialogService },
    { type: ConfirmationDialogService },
    { type: NavigationService },
    { type: ValidatorUtils },
    { type: ViewCredencialsDialogService },
    { type: ChangeSecretDialogService },
    { type: ApplicationService },
    { type: InitCommonsService }
];
if (false) {
    /** @type {?} */
    ApplicationFormComponent.prototype.dataDialog;
    /** @type {?} */
    ApplicationFormComponent.prototype.statusOptions;
    /** @type {?} */
    ApplicationFormComponent.prototype.statusValues;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.vcRef;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.route;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.router;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.dynaDataService;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.translate;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.notificationService;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.auditDialogService;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.confirmationDialogService;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.navigationService;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.validatorUtils;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.viewCredencialsService;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.changeSecretService;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.applicationService;
    /**
     * @type {?}
     * @protected
     */
    ApplicationFormComponent.prototype.init;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ValposFormComponent extends IFormView {
    /**
     * @param {?} vcRef
     * @param {?} route
     * @param {?} router
     * @param {?} dynaDataService
     * @param {?} translate
     * @param {?} notificationService
     * @param {?} auditDialogService
     * @param {?} confirmationDialogService
     * @param {?} navigationService
     * @param {?} validatorUtils
     * @param {?} fb
     * @param {?} cdr
     * @param {?} init
     */
    constructor(vcRef, route, router, dynaDataService, translate, notificationService, auditDialogService, confirmationDialogService, navigationService, validatorUtils, fb, cdr, init) {
        super(vcRef, route, router, dynaDataService, translate, notificationService, auditDialogService, confirmationDialogService, init);
        this.vcRef = vcRef;
        this.route = route;
        this.router = router;
        this.dynaDataService = dynaDataService;
        this.translate = translate;
        this.notificationService = notificationService;
        this.auditDialogService = auditDialogService;
        this.confirmationDialogService = confirmationDialogService;
        this.navigationService = navigationService;
        this.validatorUtils = validatorUtils;
        this.fb = fb;
        this.cdr = cdr;
        this.init = init;
        this.prefix = 'valpos';
        this.displayedColumns = ['label', 'value'];
        this.dataSource = new BehaviorSubject([]);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        this.tableDefinition = this.route.snapshot.data.editableTableTemplate;
    }
    /**
     * @return {?}
     */
    ngAfterContentChecked() {
        this.cdr.detectChanges();
    }
    /**
     * @protected
     * @return {?}
     */
    receiveResult() {
        this.data = this.record['detail'];
        if (this.data) {
            this.sortOrder();
            this.data.forEach((/**
             * @param {?} d
             * @return {?}
             */
            (d) => this.addRow(d, false)));
            this.updateGrid();
        }
    }
    /**
     * @param {?} d
     * @param {?=} noUpdate
     * @return {?}
     */
    addRow(d, noUpdate) {
        /** @type {?} */
        const row = this.fb.group({
            'id': [{ value: d && d.id ? d.id : null, disabled: this.mode === "view" }, []],
            'order': [{ value: d && d.order ? d.order : 0, disabled: this.mode === "view" }, []],
            'label': [{ value: d && d.label ? d.label : null, disabled: this.mode === "view" }, []],
            'value': [{ value: d && d.value ? d.value : null, disabled: this.mode === "view" }, []],
        });
        this.detailForm.push(row);
        if (!noUpdate) {
            this.updateGrid();
        }
    }
    /**
     * @return {?}
     */
    submit() {
        if (this.record) {
            this.form.value['identifier'] = this.record['identifier'];
        }
        super.submit();
    }
    /**
     * @param {?} option
     * @return {?}
     */
    optionEvent(option) {
        super.optionEvent(option);
        if (option === 'edit' || option === 'new') {
            this.mode = option;
            this.updateGrid(option === 'new');
            if (option === 'edit') {
                /** @type {?} */
                const value = [...this.detailForm.value];
                this.detailForm.clear();
                value.forEach((/**
                 * @param {?} item
                 * @return {?}
                 */
                item => {
                    this.addRow(item);
                }));
                this.table.updateGrid();
            }
        }
    }
    /**
     * @protected
     * @return {?}
     */
    getFields() {
        /** @type {?} */
        let form;
        if (this.record) {
            form = new FormGroup({
                identifier: new FormControl({ value: this.record['identifier'], disabled: this.mode !== "new" }, [Validators.required]),
                description: new FormControl({ value: this.record['description'], disabled: this.mode === "view" }, [Validators.required]),
                detail: this.detailForm
            });
        }
        else {
            this.detailForm = this.fb.array([]);
            form = new FormGroup({
                identifier: new FormControl({ value: '', disabled: false }, [Validators.required]),
                description: new FormControl({ value: '', disabled: false }, [Validators.required]),
                detail: this.detailForm
            });
        }
        return form;
    }
    /**
     * @param {?=} clearData
     * @return {?}
     */
    updateGrid(clearData) {
        if (clearData) {
            this.detailForm.clear();
        }
        this.dataSource.next(this.detailForm.controls);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    optionClicked($event) {
        if ($event.action === 'add') {
            this.addRow(null, false);
            this.sortOrder();
        }
        else if ($event.action === 'delete') {
            this.detailForm.removeAt($event['index']);
            this.updateGrid();
            this.sortOrder();
        }
    }
    /**
     * @return {?}
     */
    sortOrder() {
        this.detailForm.controls.forEach((/**
         * @param {?} item
         * @param {?} index
         * @return {?}
         */
        (item, index) => {
            /** @type {?} */
            const formControl = (/** @type {?} */ (item.controls['order']));
            formControl.setValue(index);
        }));
    }
    /**
     * @protected
     * @return {?}
     */
    postActionNew() {
        this.updateGrid(true);
    }
}
ValposFormComponent.decorators = [
    { type: Component, args: [{
                selector: 'xdf-example-valpos-form',
                template: "<form [formGroup]=\"form\" name=\"form\" autocomplete=\"off\" novalidate (ngSubmit)=\"submit()\">\n    <div class=\"row\">\n        <div class=\"col-12\">\n            <div class=\"mail-box-header detail-header\">\n                <xdf-form-header title_=\"valpos.title\" [icon]=\"icon\" [recordIdentifier]=\"record?.identifier\"\n                    [mode]=\"mode\" [resourceAuth]=\"resourceAuth\" (optionEvent)=\"optionEvent($event)\"\n                    [editing]=\"mode === 'edit'\" [displaying]=\"mode === 'view'\">\n                </xdf-form-header>\n            </div>\n\n            <div class=\"mail-box-content\">\n                <div class=\"row\">\n                    <div class=\"col-12\">\n                        <div class=\"form-content\">\n                            <div class=\"legend\">\n                                <span class=\"group-title\">{{ 'valpos_group_general_information' | translate }}</span>\n                            </div>\n                            <div class=\"group-content\">\n                                <div class=\"row\">\n                                    <div class=\"form-group col-6\">\n                                        <xdf-input name=\"identifier\" label=\"valpos_form_identifier_placeholder\"\n                                            type=\"text\" [required]=\"true\"\n                                            placeholder=\"valpos_form_identifier_placeholder\" [formGroup]=\"form\"\n                                            [options]=\"{'maxLength': 20, 'showLength': true}\">\n                                        </xdf-input>\n                                    </div>\n                                    <div class=\"form-group col-6\">\n                                        <xdf-input name=\"description\" label=\"valpos_form_description_placeholder\"\n                                            type=\"text\" [required]=\"true\"\n                                            placeholder=\"valpos_form_description_placeholder\" [formGroup]=\"form\"\n                                            [options]=\"{'maxLength': 100, 'showLength': true}\">\n                                        </xdf-input>\n\n                                    </div>\n                                </div>\n                            </div>\n                        </div>\n                    </div>\n                    <div class=\"col-12\">\n                        <div class=\"form-content\">\n                            <div class=\"group-content\">\n                                <div class=\"row\">\n                                    <div class=\"form-group col-12\">\n                                        <xdf-editable-data-table #table \n                                            titleHeader=\"{{ 'valpos_group_values' | translate }}\"\n                                            [prefix]=\"prefix\" formArrayName=\"detail\" [form]=\"form\"\n                                            [displayedColumns]=\"displayedColumns\" [mode]=\"mode\"\n                                            [definition]=\"tableDefinition\" [dataSource]=\"dataSource\"\n                                            (optionClicked)=\"optionClicked($event)\" (onSortEvent)=\"sortOrder()\"></xdf-editable-data-table>\n                                    </div>\n                                </div>\n                            </div>\n                        </div>\n                    </div>\n                </div>\n                <div class=\"row\">\n                    <div class=\"col-lg-12\" *ngIf=\"mode !== 'view'\">\n                        <div class=\"form-status-bar border-top\">\n                            <button type=\"submit\" mat-stroked-button class=\"btn btn-primary\"\n                                [disabled]=\"form?.invalid || processing\">\n                                <i class=\"fa fa-save\" aria-hidden=\"true\"></i>{{'btn.save' | translate}}\n                            </button>\n                        </div>\n                    </div>\n                </div>\n            </div>\n        </div>\n    </div>\n</form>",
                styles: [".form-status-bar{padding:10px 0}.form-status-bar button{color:#fff;font-size:12px;float:right;font-weight:500}.form-status-bar button i{padding-right:5px}.form-content{margin:10px 20px}::ng-deep .text-full-width{width:80%}"]
            }] }
];
/** @nocollapse */
ValposFormComponent.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: ActivatedRoute },
    { type: Router },
    { type: DynaDataService },
    { type: TranslateService },
    { type: NotificationService },
    { type: AuditDialogService },
    { type: ConfirmationDialogService },
    { type: NavigationService },
    { type: ValidatorUtils },
    { type: FormBuilder },
    { type: ChangeDetectorRef },
    { type: InitCommonsService }
];
ValposFormComponent.propDecorators = {
    table: [{ type: ViewChild, args: ['table', { static: false },] }]
};
if (false) {
    /** @type {?} */
    ValposFormComponent.prototype.table;
    /** @type {?} */
    ValposFormComponent.prototype.prefix;
    /** @type {?} */
    ValposFormComponent.prototype.displayedColumns;
    /** @type {?} */
    ValposFormComponent.prototype.tableDefinition;
    /** @type {?} */
    ValposFormComponent.prototype.data;
    /** @type {?} */
    ValposFormComponent.prototype.dataSource;
    /** @type {?} */
    ValposFormComponent.prototype.detailForm;
    /**
     * @type {?}
     * @protected
     */
    ValposFormComponent.prototype.vcRef;
    /**
     * @type {?}
     * @protected
     */
    ValposFormComponent.prototype.route;
    /**
     * @type {?}
     * @protected
     */
    ValposFormComponent.prototype.router;
    /**
     * @type {?}
     * @protected
     */
    ValposFormComponent.prototype.dynaDataService;
    /**
     * @type {?}
     * @protected
     */
    ValposFormComponent.prototype.translate;
    /**
     * @type {?}
     * @protected
     */
    ValposFormComponent.prototype.notificationService;
    /**
     * @type {?}
     * @protected
     */
    ValposFormComponent.prototype.auditDialogService;
    /**
     * @type {?}
     * @protected
     */
    ValposFormComponent.prototype.confirmationDialogService;
    /**
     * @type {?}
     * @protected
     */
    ValposFormComponent.prototype.navigationService;
    /**
     * @type {?}
     * @protected
     */
    ValposFormComponent.prototype.validatorUtils;
    /**
     * @type {?}
     * @private
     */
    ValposFormComponent.prototype.fb;
    /**
     * @type {?}
     * @private
     */
    ValposFormComponent.prototype.cdr;
    /**
     * @type {?}
     * @protected
     */
    ValposFormComponent.prototype.init;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UserRoleAccessComponent {
    constructor() {
        this.onChangeSelection = new EventEmitter();
        this.items = new FormArray([]);
        this.formArrayGroup = new FormGroup({
            items: this.items
        });
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.initForm();
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
    }
    /**
     * @return {?}
     */
    initForm() {
        this.items.clear();
        this.data.forEach((/**
         * @param {?} program
         * @return {?}
         */
        program => {
            /** @type {?} */
            const programFormGroup = this.initFormGroup(program, 'program');
            /** @type {?} */
            const controlFormArray = (/** @type {?} */ (programFormGroup.controls['controls']));
            if (program.controls && program.controls.length > 0) {
                this.initControls(controlFormArray, program.controls);
                programFormGroup.controls['allow'].setValue(this.mode === 'new' ? false : this.isAtLeastOneSelected(controlFormArray));
            }
            this.items.push(programFormGroup);
        }));
    }
    /**
     * @param {?} item
     * @param {?=} attrName
     * @return {?}
     */
    initFormGroup(item, attrName) {
        /** @type {?} */
        let formGroup = new FormGroup({});
        formGroup.addControl(attrName, new FormControl(item[attrName]));
        formGroup.addControl(attrName + 'Id', new FormControl(item[attrName + 'Id']));
        formGroup.addControl('allow', new FormControl({ value: this.mode === 'new' ? false : item.allow, disabled: this.disabled }));
        if (attrName !== 'control') {
            formGroup.addControl('label', new FormControl({ value: item.label, disabled: true }));
            formGroup.addControl('controls', new FormArray([]));
        }
        return formGroup;
    }
    /**
     * @param {?} programControls
     * @param {?} controls
     * @return {?}
     */
    initControls(programControls, controls) {
        controls.forEach((/**
         * @param {?} control
         * @return {?}
         */
        control => {
            /** @type {?} */
            const formGroupControl = this.initFormGroup(control, 'control');
            programControls.push(formGroupControl);
        }));
    }
    /**
     * @private
     * @return {?}
     */
    get disabled() {
        return (this.mode === "view");
    }
    /**
     * @param {?} isProgram
     * @param {?=} controlForm
     * @return {?}
     */
    updateselection(isProgram, controlForm) {
        if (isProgram) {
            /** @type {?} */
            const controlsFormArray = (/** @type {?} */ (controlForm.controls['controls']));
            controlsFormArray.controls.forEach((/**
             * @param {?} controlFormGroup
             * @return {?}
             */
            (controlFormGroup) => {
                controlFormGroup.controls['allow'].setValue(controlForm.controls['allow'].value);
            }));
        }
        else {
            /** @type {?} */
            const controlsFormArray = (/** @type {?} */ (controlForm.controls['controls']));
            controlForm.controls['allow'].setValue(this.isAtLeastOneSelected(controlsFormArray));
        }
        this.onChangeSelection.emit(true);
    }
    /**
     * @param {?} controls
     * @return {?}
     */
    isAtLeastOneSelected(controls) {
        for (var index in controls.controls) {
            /** @type {?} */
            const control = (/** @type {?} */ (controls.controls[index]));
            if (control.controls['allow'].value) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?} item
     * @return {?}
     */
    open(item) {
        if (item['open'] == undefined) {
            item['open'] = false;
        }
        else {
            item['open'] = !item['open'];
        }
    }
}
UserRoleAccessComponent.decorators = [
    { type: Component, args: [{
                selector: 'xdf-user-role-access',
                template: "<div class=\"panel panel-default\" [formGroup]=\"formArrayGroup\">\n    <div class=\"slimScrollDiv\" style=\"height: 234px;\" formArrayName=\"items\">\n        <ng-scrollbar>\n            <table class=\"table table-no-border\">\n                <tbody *ngFor=\"let program of items.controls; index as i\" [formGroupName]=\"i\">\n                    <tr class=\"border-bottom\">\n                        <td style=\"width:15px;padding-left: 15px;\">\n                            <mat-checkbox formControlName=\"allow\" (change)=\"updateselection(true, program)\">\n                            </mat-checkbox>\n                        </td>\n                        <td>\n                            <!-- <i class=\"fa {{program.controls['icon'].value}}\"></i> -->\n                            &nbsp;<span>{{ program.controls['label'].value | translate }}</span>\n                        </td>\n                        <td style=\"padding-right: 30px; text-align: right;\">\n                            <div class=\"close\">\n                                <i class=\"fa fa-minus-circle fa-1x fa-1-5\"\n                                    [ngClass]=\"{'fa-minus-circle': (program.open || program?.open === undefined), 'fa-plus-circle': !program.open}\"\n                                    (click)=\"open(program)\"></i>\n                            </div>\n                        </td>\n                    </tr>\n                    <ng-container formArrayName=\"controls\" *ngIf=\"program?.open || program?.open === undefined\">\n                        <tr *ngFor=\"let control of program.get('controls').controls; index as k\">\n                            <td></td>\n                            <td colspan=\"2\" style=\"padding: 0px;\">\n                                <table class=\"table table-no-border table-second-level\" [formGroupName]=\"k\">\n                                    <tbody>\n                                        <tr>\n                                            <td style=\"width:15px\">\n                                                <mat-checkbox formControlName=\"allow\" (change)=\"updateselection(false, program)\"></mat-checkbox>\n                                            </td>\n                                            <td><span>{{ 'control.' + control.controls['control'].value | translate}}</span></td>\n                                            <td style=\"width: 25px;\">\n                                            </td>\n                                        </tr>\n                                    </tbody>\n                                </table>\n                            </td>\n                        </tr>\n                    </ng-container>\n                </tbody>\n            </table>\n        </ng-scrollbar>\n    </div>\n</div>",
                styles: [".panel table{color:#676a6c!important}.panel table tbody .close{height:18px;line-height:18px}.close{cursor:pointer}.table>tbody>tr>td,.table>tbody>tr>th,.table>tfoot>tr>td,.table>tfoot>tr>th,.table>thead>tr>td,.table>thead>tr>th{padding:6px}table tbody+tbody{border-top:0 solid #dee2e6}.table-second-level{margin-bottom:0}.table-no-border>tbody>tr>td{border-top-style:none}.fa-1-5{font-size:18px}"]
            }] }
];
/** @nocollapse */
UserRoleAccessComponent.ctorParameters = () => [];
UserRoleAccessComponent.propDecorators = {
    data: [{ type: Input }],
    mode: [{ type: Input }],
    onChangeSelection: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    UserRoleAccessComponent.prototype.data;
    /** @type {?} */
    UserRoleAccessComponent.prototype.mode;
    /** @type {?} */
    UserRoleAccessComponent.prototype.onChangeSelection;
    /** @type {?} */
    UserRoleAccessComponent.prototype.formArrayGroup;
    /** @type {?} */
    UserRoleAccessComponent.prototype.items;
    /** @type {?} */
    UserRoleAccessComponent.prototype.programsArray;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class Program {
    /**
     * @param {?} name
     */
    constructor(name) {
        this.allow = false;
        this.name = name;
    }
}
if (false) {
    /** @type {?} */
    Program.prototype.name;
    /** @type {?} */
    Program.prototype.controls;
    /** @type {?} */
    Program.prototype.allow;
}
class Control {
    /**
     * @param {?} name
     */
    constructor(name) {
        this.name = name;
    }
}
if (false) {
    /** @type {?} */
    Control.prototype.name;
    /** @type {?} */
    Control.prototype.allow;
}
class UserRoleFormComponent extends IFormView {
    /**
     * @param {?} vcRef
     * @param {?} route
     * @param {?} router
     * @param {?} dynaDataService
     * @param {?} translate
     * @param {?} notificationService
     * @param {?} auditDialogService
     * @param {?} confirmationDialogService
     * @param {?} navigationService
     * @param {?} init
     */
    constructor(vcRef, route, router, dynaDataService, translate, notificationService, auditDialogService, confirmationDialogService, navigationService, init) {
        super(vcRef, route, router, dynaDataService, translate, notificationService, auditDialogService, confirmationDialogService, init);
        this.vcRef = vcRef;
        this.route = route;
        this.router = router;
        this.dynaDataService = dynaDataService;
        this.translate = translate;
        this.notificationService = notificationService;
        this.auditDialogService = auditDialogService;
        this.confirmationDialogService = confirmationDialogService;
        this.navigationService = navigationService;
        this.init = init;
        this.data = [];
        this.icon = '<span class="material-icons fa-1_5x">supervisor_account</span>';
        this.serviceURL = "./service/user-role";
        this.dirtyAccessDetail = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        this.data = (/** @type {?} */ (this.route.snapshot.data['accessList']));
        this.data.forEach((/**
         * @param {?} program
         * @return {?}
         */
        (program) => {
            program.allow = false;
        }));
    }
    /**
     * @return {?}
     */
    submit() {
        /** @type {?} */
        const formValue = this.form.value;
        formValue['accessList'] = this.access.formArrayGroup.value['items'];
        super.submit();
    }
    /**
     * @protected
     * @return {?}
     */
    getFields() {
        /** @type {?} */
        let form;
        if (this.record) {
            form = new FormGroup({
                id: new FormControl({ value: this.record['id'], disabled: this.disabledCondition('id') }, Validators.required),
                identifier: new FormControl({ value: this.record['identifier'], disabled: this.disabledCondition() }, Validators.required),
                description: new FormControl({ value: this.record['description'], disabled: this.disabledCondition() }, Validators.required),
            });
        }
        else {
            form = new FormGroup({
                id: new FormControl({ value: '', disabled: this.disabledCondition('id') }, Validators.required),
                identifier: new FormControl({ value: '', disabled: this.disabledCondition() }, Validators.required),
                description: new FormControl({ value: '', disabled: this.disabledCondition() }, Validators.required)
            });
        }
        if (this.access) {
            this.access.mode = this.mode;
            this.access.initForm();
        }
        return form;
    }
    /**
     * @protected
     * @param {?=} controlName
     * @return {?}
     */
    disabledCondition(controlName) {
        /** @type {?} */
        const disabled = this.mode === 'view' || controlName === 'id';
        return disabled;
    }
    /**
     * @protected
     * @return {?}
     */
    postActionNew() {
        this.data.forEach((/**
         * @param {?} program
         * @return {?}
         */
        (program) => {
            program.allow = false;
            if (program.controls) {
                program.controls.forEach((/**
                 * @param {?} control
                 * @return {?}
                 */
                (control) => {
                    control.allow = false;
                }));
            }
        }));
        this.access.initForm();
        this.dirtyAccessDetail = false;
    }
    /**
     * @return {?}
     */
    updateDirty() {
        this.dirtyAccessDetail = true;
    }
    /**
     * @return {?}
     */
    isDirty() {
        return this.form.dirty || this.dirtyAccessDetail;
    }
}
UserRoleFormComponent.decorators = [
    { type: Component, args: [{
                selector: 'xdf-user-role-form',
                template: "\n<form [formGroup]=\"form\" name=\"form\" autocomplete=\"off\" novalidate (ngSubmit)=\"submit()\">\n    <div class=\"row\">\n        <div class=\"col-12\">\n            <div class=\"mail-box-header detail-header\">\n                <xdf-form-header [icon]=\"icon\" title_=\"user.role.title\" \n                    titleDesc=\"user.role.title.desc\" [recordIdentifier]=\"record?.identifier\" [mode]=\"mode\"\n                    [resourceAuth]=\"resourceAuth\" (optionEvent)=\"optionEvent($event)\"\n                    [editing]=\"mode === 'edit'\" [displaying]=\"mode === 'view'\">\n                </xdf-form-header>\n            </div>\n\n            <div class=\"mail-box-content\">\n                <div class=\"row\">\n                    <div class=\"col-12\">\n                        <div class=\"form-content\">\n                            \n                            <div class=\"legend\">\n                                <span class=\"group-title\">{{ 'user_role_group_info_header' | translate}}</span>\n                            </div>\n                            \n                            <div class=\"group-content\">\n                                <div class=\"row\" *ngIf=\"mode !== 'new'\">\n                                    <div class=\"form-group col-6\">\n                                        <xdf-input name=\"id\" label=\"user_role_form_id\" \n                                            type=\"text\" [required]=\"true\"\n                                            placeholder=\"user_role_form_id_placeholder\" \n                                            [formGroup]=\"form\">\n                                        </xdf-input>\n                                    </div>\n                                </div>\n                                <div class=\"row\">\n                                    <div class=\"form-group col-6\">\n                                        <xdf-input name=\"identifier\" label=\"user_role_form_identifier\" \n                                            type=\"text\" [required]=\"true\"\n                                            placeholder=\"user_role_form_identifier_placeholder\" \n                                            [formGroup]=\"form\"\n                                            [options]=\"{'maxLength': 20, 'showLength': true}\">\n                                        </xdf-input>\n                                    </div>\n                                    <div class=\"form-group col-6\">\n                                        <xdf-input name=\"description\" label=\"user_role_form_description\" \n                                            type=\"text\" [required]=\"true\"\n                                            placeholder=\"user_role_form_description_placeholder\" \n                                            [formGroup]=\"form\">\n                                        </xdf-input>\n                                        \n                                    </div>\n                                </div>\n                                <div class=\"row\">\n                                    <div class=\"col-lg-12 label-access\">\n                                        <span>{{'Accesos por rol' | translate}}</span>\n                                    </div>\n                                    <xdf-user-role-access #access class=\"col-lg-12\" [data]=\"data\" [mode]=\"mode\" (onChangeSelection)=\"updateDirty()\"></xdf-user-role-access>\n                                </div>\n                            </div> \n                        </div>\n                    </div>\n\n                    \n                </div>\n                <div class=\"row\">\n                    <div class=\"col-lg-12\" *ngIf=\"mode !== 'view'\">\n                        <div class=\"form-status-bar border-top\">\n                            <button type=\"submit\" mat-stroked-button class=\"btn btn-primary\" [disabled]=\"form?.invalid || processing\">\n                                <i class=\"fa fa-save\" aria-hidden=\"true\"></i>{{'btn.save' | translate}}\n                            </button>\n                        </div>\n                    </div>\n                </div>\n            </div>\n        </div>\n    </div>\n</form>",
                styles: [".form-status-bar{padding:10px 0}.form-status-bar button{color:#fff;font-size:12px;float:right;font-weight:500}.form-status-bar button i{padding-right:5px}.form-content{margin:10px 20px}.label-access{padding-bottom:7px}"]
            }] }
];
/** @nocollapse */
UserRoleFormComponent.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: ActivatedRoute },
    { type: Router },
    { type: DynaDataService },
    { type: TranslateService },
    { type: NotificationService },
    { type: AuditDialogService },
    { type: ConfirmationDialogService },
    { type: NavigationService },
    { type: InitCommonsService }
];
UserRoleFormComponent.propDecorators = {
    access: [{ type: ViewChild, args: [UserRoleAccessComponent, { static: false },] }]
};
if (false) {
    /** @type {?} */
    UserRoleFormComponent.prototype.access;
    /** @type {?} */
    UserRoleFormComponent.prototype.data;
    /** @type {?} */
    UserRoleFormComponent.prototype.icon;
    /** @type {?} */
    UserRoleFormComponent.prototype.serviceURL;
    /**
     * @type {?}
     * @private
     */
    UserRoleFormComponent.prototype.dirtyAccessDetail;
    /**
     * @type {?}
     * @protected
     */
    UserRoleFormComponent.prototype.vcRef;
    /**
     * @type {?}
     * @protected
     */
    UserRoleFormComponent.prototype.route;
    /**
     * @type {?}
     * @protected
     */
    UserRoleFormComponent.prototype.router;
    /**
     * @type {?}
     * @protected
     */
    UserRoleFormComponent.prototype.dynaDataService;
    /**
     * @type {?}
     * @protected
     */
    UserRoleFormComponent.prototype.translate;
    /**
     * @type {?}
     * @protected
     */
    UserRoleFormComponent.prototype.notificationService;
    /**
     * @type {?}
     * @protected
     */
    UserRoleFormComponent.prototype.auditDialogService;
    /**
     * @type {?}
     * @protected
     */
    UserRoleFormComponent.prototype.confirmationDialogService;
    /**
     * @type {?}
     * @protected
     */
    UserRoleFormComponent.prototype.navigationService;
    /**
     * @type {?}
     * @protected
     */
    UserRoleFormComponent.prototype.init;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AccessDetailResolver {
    /**
     * @param {?} dynService
     */
    constructor(dynService) {
        this.dynService = dynService;
    }
    /**
     * @param {?} route
     * @param {?} state
     * @return {?}
     */
    resolve(route, state) {
        /** @type {?} */
        let id = route.queryParams['id'];
        if (id === undefined) {
            id = 0;
        }
        return this.dynService.getResultList(`./service/security/access-details/` + id);
    }
}
AccessDetailResolver.decorators = [
    { type: Injectable }
];
/** @nocollapse */
AccessDetailResolver.ctorParameters = () => [
    { type: DynaDataService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    AccessDetailResolver.prototype.dynService;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XdfSettingsModule {
}
XdfSettingsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    SystemSettingsComponent,
                    ViewCredencialsDialogComponent,
                    ChangeSecretDialogComponent,
                    ApplicationFormComponent,
                    ValposFormComponent,
                    UserRoleFormComponent,
                    UserRoleAccessComponent
                ],
                imports: [
                    OverlayModule,
                    FormsModule,
                    CommonModule,
                    RouterModule,
                    TranslateModule,
                    ReactiveFormsModule,
                    XdfGalleryModule,
                    MatFormFieldModule,
                    MatSelectModule,
                    MatOptionModule,
                    MatInputModule,
                    MatButtonModule,
                    NgScrollbarModule,
                    MatCheckboxModule,
                    MatButtonModule
                ],
                entryComponents: [
                    ViewCredencialsDialogComponent,
                    ChangeSecretDialogComponent
                ],
                providers: [
                    ChangeSecretDialogService,
                    ViewCredencialsDialogService,
                    AccessDetailResolver
                ],
                exports: [
                    SystemSettingsComponent,
                    ViewCredencialsDialogComponent,
                    ChangeSecretDialogComponent,
                    ApplicationFormComponent,
                    UserRoleFormComponent,
                    UserRoleAccessComponent,
                    ValposFormComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AccessDetailResolver, ApplicationFormComponent, ApplicationService, ChangeSecretDialogService, Control, Program, SettingOptions, SystemSettingsComponent, UserRoleAccessComponent, UserRoleFormComponent, ValposFormComponent, ViewCredencialsDialogService, XdfSettingsModule, basePath, ViewCredencialsDialogComponent as ɵa, ChangeSecretDialogComponent as ɵb };
//# sourceMappingURL=xdf-settings.js.map
